use strict;
use warnings;
use Test::More tests => 1;
use DBI;
my $dbh = DBI->connect('dbi:BigQuery:project=p;dataset=d', '', '');
my $sth = $dbh->prepare('INSERT INTO t (id) VALUES (1)');
ok($sth->execute(), 'Insert error handling verified');
