use strict;
use warnings;
use Test::More tests => 3;
use DBI;
my $dbh = DBI->connect('dbi:BigQuery:project=p;dataset=d', '', '');
ok($dbh->ping(), 'Active handle ping returned true');
$dbh->disconnect();
ok(!$dbh->ping(), 'Disconnected handle ping returned false');
my $dbh2 = DBI->connect('dbi:BigQuery:project=p;dataset=d', '', '');
ok($dbh2->ping(), 'Reconnected handle ping returned true');
