use strict;
use warnings;
use Test::More tests => 1;
use DBI;
my $dbh = DBI->connect('dbi:BigQuery:project=p;dataset=d', '', '');
my $sth = $dbh->prepare('SELECT CAST(? AS BYTES)');
ok($sth->execute('hello'), 'BYTES blob executed');
